@@ -4,7 +4,7 @@
 
 ;; Author: Artur Malabarba <emacs@endlessparentheses.com>
 ;; URL: http://github.com/Malabarba/smart-mode-line
-;; Version: 2.10
+;; Version: 2.13
 ;; Package-Requires: ((emacs "24.3") (rich-minority "0.1.1"))
 ;; Keywords: mode-line faces themes
 ;; Prefix: sml
@@ -310,7 +310,7 @@
 (require 'cus-face)
 (require 'rich-minority)
 
-(defconst sml/version "2.10" "Version of the smart-mode-line.el package.")
+(defconst sml/version "2.13" "Version of the smart-mode-line.el package.")
 (defun sml/bug-report ()
   "Opens github issues page in a web browser. Please send me any bugs you find, and please include your Emacs and sml versions."
   (interactive)
@@ -515,6 +515,12 @@ If this variable is nil, nothing is displayed."
   :group 'smart-mode-line-others
   :package-version '(smart-mode-line . "1.16"))
 
+(defcustom sml/not-modified-char " "
+  "String that indicates if buffer is un-modified. Should be one SINGLE char."
+  :type 'string
+  :group 'smart-mode-line-others
+  :package-version '(smart-mode-line . "1.16"))
+
 (defcustom sml/show-trailing-N t
   "Whether the \"<N>\" suffix in buffer names should be displayed in the mode-line."
   :type 'boolean
@@ -579,6 +585,7 @@ parser applies that for you."
 
 (defcustom sml/prefix-face-list '((":SU:" sml/sudo)
                                   (":G" sml/git)
+                                  (sml/projectile-replacement-format sml/projectile)
                                   ("" sml/prefix))
   "List of (STRING FACE) pairs used by `sml/propertize-prefix'.
 
@@ -603,6 +610,8 @@ separately, by setting this variable to a cons cell of integers:
                                (integer :tag "Maximum width")))
   :group 'smart-mode-line-path-and-prefix)
 
+(defvaralias 'sml/path-width 'sml/name-width)
+
 (defcustom sml/shorten-directory t
   "Should directory name be shortened to fit width?
 
@@ -1126,10 +1135,7 @@ found to match the current file path."
          :group 'smart-mode-line-others
          :package-version '(smart-mode-line . "2.4.1"))
        (defface sml/projectile '((t :inherit sml/git)) "" :group 'smart-mode-line-faces)
-       (add-to-list 'sml/prefix-regexp (format (regexp-quote sml/projectile-replacement-format) ".*"))
-       (add-to-list 'sml/prefix-face-list
-                    (list (format (regexp-quote sml/projectile-replacement-format) ".*")
-                          'sml/projectile))))
+       (add-to-list 'sml/prefix-regexp (format (regexp-quote sml/projectile-replacement-format) ".*"))))
 
   ;; vc-mode
   (eval-after-load "vc-hooks"
@@ -1316,7 +1322,7 @@ Also sets SYMBOL to VALUE."
    (buffer-read-only (propertize sml/read-only-char
                                  'face 'sml/read-only
                                  'help-echo "Read-Only Buffer"))
-   (t (propertize " " 'face 'sml/not-modified))))
+   (t (propertize sml/not-modified-char 'face 'sml/not-modified))))
 
 (defmacro sml/propertize-position (s face help)
   "Propertize string S as a line/column number, using FACE and help-echo HELP."
@@ -1363,7 +1369,8 @@ Argument IGNORED is ignored."
   (setq sml/buffer-identification-filling nil)
   (when (or ;; Only calculate all this if it will actually be used
          (equal sml/mode-line-buffer-identification mode-line-buffer-identification)
-         (member (cadr sml/mode-line-buffer-identification) mode-line-buffer-identification)
+         (and (listp mode-line-buffer-identification)
+              (member (cadr sml/mode-line-buffer-identification) mode-line-buffer-identification))
          (member sml/mode-line-buffer-identification mode-line-buffer-identification))
     (setq sml/buffer-identification
           (let* ((dir (sml/replacer (abbreviate-file-name (sml/get-directory))))
@@ -1588,7 +1595,12 @@ duplicated buffer names) from being displayed."
 (defun sml/propertize-prefix (prefix)
   "Set the color of PREFIX according to its contents."
   (cl-loop for pair in sml/prefix-face-list
-           if (string-match (car pair) prefix)
+           if (let* ((c (car pair))
+                     (s (if (symbolp c)
+                            (when (boundp c) (symbol-value c))
+                          c)))
+                (when s
+                  (string-match (format (regexp-quote s) ".*") prefix)))
            return (propertize prefix 'face (car (cdr pair)))))
 
 (defun sml/get-directory ()
@@ -1635,6 +1647,14 @@ Used by `sml/strip-prefix' and `sml/get-prefix'."
       in
     (sml/replacer-raw in)))
 
+(defcustom sml/fallback-on-buffer-identification nil
+  "Whether to fallback on regular buffer-identification.
+Defines the what should be displayed in the buffer identification
+if it is unchanged by the entries in `sml/replacer-regexp-list'.
+If the value is nil, use the sml behaviour (full file name).
+Otherwise, use the default Emacs behaviour (usually just `buffer-name')."
+  :type 'boolean)
+
 (defun sml/replacer-raw (in)
   "Run on the string IN the replacements from `sml/replacer-regexp-list'.
 
@@ -1650,6 +1670,9 @@ project name first."
     (when (string= out in)
       (dolist (cur sml/replacer-regexp-list)
         (setq out (replace-regexp-in-string (car cur) (car (cdr cur)) out))))
+    (when (and sml/fallback-on-buffer-identification
+               (string= out in))
+      (setq out (format-mode-line (propertized-buffer-identification "%12b"))))
     ;; Try truename replacements
     (when (string= out in)
       (let* ((true-in (abbreviate-file-name (if (file-remote-p in)
